@@ -190,7 +190,7 @@ public class Memorizer implements Runnable {
                 try {
                     memorizeContact(address, ctx, userConfig);
                 } catch (final AbstractOXException e) {
-                    LOG.error("Contact collector run aborted for address: " + address.toUnicodeString(), e);
+                    LOG.warn("Contact collector run aborted for address: " + address.toUnicodeString(), e);
                 }
             }
         }
@@ -202,11 +202,11 @@ public class Memorizer implements Runnable {
             contact = transformInternetAddress(address);
         } catch (final ParseException e) {
             // Decoding failed; ignore contact
-            LOG.error(e.getMessage(), e);
+            LOG.warn(e.getMessage(), e);
             return -1;
         } catch (final UnsupportedEncodingException e) {
             // Decoding failed; ignore contact
-            LOG.error(e.getMessage(), e);
+            LOG.warn(e.getMessage(), e);
             return -1;
         }
         final ContactInterface contactInterface =
@@ -288,7 +288,7 @@ public class Memorizer implements Runnable {
     private int getFolderId() {
         int retval = 0;
         try {
-            final Integer folder = ServerUserSetting.getContactCollectionFolder(session.getContextId(), session.getUserId());
+            final Integer folder = ServerUserSetting.getInstance().getContactCollectionFolder(session.getContextId(), session.getUserId());
             if (null != folder) {
                 retval = folder.intValue();
             }
@@ -300,16 +300,16 @@ public class Memorizer implements Runnable {
 
     private boolean isEnabled() {
         Boolean enabled = null;
-        Boolean enabledRight = null;
+        boolean enabledRight = false;
         try {
-            enabled = ServerUserSetting.isContactCollectionEnabled(session.getContextId(), session.getUserId());
+            enabled = ServerUserSetting.getInstance().isContactCollectionEnabled(session.getContextId(), session.getUserId());
             enabledRight = new ServerSessionAdapter(session).getUserConfiguration().isCollectEmailAddresses();
         } catch (final SettingException e) {
             LOG.error(e.getMessage(), e);
         } catch (final ContextException e) {
             LOG.error(e.getMessage(), e);
         }
-        return enabled != null && enabledRight != null && enabled.booleanValue() && enabled.booleanValue();
+        return enabledRight && enabled != null && enabled.booleanValue();
     }
 
     private Contact transformInternetAddress(final InternetAddress address) throws ParseException, UnsupportedEncodingException {
